Index: /trunk/src/VBox/Main/GuestImpl.cpp
===================================================================
--- /trunk/src/VBox/Main/GuestImpl.cpp	(revision 35069)
+++ /trunk/src/VBox/Main/GuestImpl.cpp	(revision 35070)
@@ -346,5 +346,5 @@
                             ULONG uBytesWritten;
                             rc = pGuest->SetProcessInput(uPID, uFlags,
-                                                         5 * 1000 /* Wait 5s for getting the input data transfered. */,
+                                                         10 * 1000 /* Wait 10s for getting the input data transfered. */,
                                                          ComSafeArrayAsInParam(aInputData), &uBytesWritten);
                             if (FAILED(rc))
@@ -607,5 +607,5 @@
                                     ULONG uBytesWritten;
                                     rc = pGuest->SetProcessInput(uPID, uFlags,
-                                                                 5 * 1000 /* Wait 5s for getting the input data transfered. */,
+                                                                 10 * 1000 /* Wait 10s for getting the input data transfered. */,
                                                                  ComSafeArrayAsInParam(aInputData), &uBytesWritten);
                                     if (FAILED(rc))
